Index: trunk/MagicSoft/Mars/mbase/MParContainer.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MParContainer.cc	(revision 852)
+++ trunk/MagicSoft/Mars/mbase/MParContainer.cc	(revision 855)
@@ -51,10 +51,10 @@
 MParContainer::MParContainer(const MParContainer &named)
 {
-    *fName = *(named.fName);
+    *fName  = *(named.fName);
     *fTitle = *(named.fTitle);
 
     fLog = named.fLog;
 
-    fHasChanged = named.fHasChanged;
+    fReadyToSave = named.fReadyToSave;
 }
 
@@ -73,6 +73,6 @@
     *fTitle = *(rhs.fTitle);
 
-    fLog        = rhs.fLog;
-    fHasChanged = rhs.fHasChanged;
+    fLog         = rhs.fLog;
+    fReadyToSave = rhs.fReadyToSave;
 
     return *this;
@@ -103,6 +103,6 @@
     *cont.fTitle = *fTitle;
 
-    cont.fLog        = fLog;
-    cont.fHasChanged = fHasChanged;
+    cont.fLog         = fLog;
+    cont.fReadyToSave = fReadyToSave;
 }
 
Index: trunk/MagicSoft/Mars/mbase/MParContainer.h
===================================================================
--- trunk/MagicSoft/Mars/mbase/MParContainer.h	(revision 852)
+++ trunk/MagicSoft/Mars/mbase/MParContainer.h	(revision 855)
@@ -35,14 +35,14 @@
 
 protected:
-    MLog    *fLog;        //! The general log facility for this object, initialized with the global object
+    MLog    *fLog;         //! The general log facility for this object, initialized with the global object
 
-    TString *fName;       //! parameter container identifier (name)
-    TString *fTitle;      //! parameter container title
+    TString *fName;        //! parameter container identifier (name)
+    TString *fTitle;       //! parameter container title
 
-    Bool_t   fHasChanged; //! should be set to true if the contents of the container is changed somehow
+    Bool_t   fReadyToSave; //! should be set to true if the contents of the container is changed somehow
 
 public:
-    MParContainer(const char *name="", const char *title="") : fLog(&gLog), fHasChanged(kFALSE) { Init(name, title); }
-    MParContainer(const TString &name, const TString &title) : fLog(&gLog), fHasChanged(kFALSE) { Init(name, title); }
+    MParContainer(const char *name="", const char *title="") : fLog(&gLog), fReadyToSave(kFALSE) { Init(name, title); }
+    MParContainer(const TString &name, const TString &title) : fLog(&gLog), fReadyToSave(kFALSE) { Init(name, title); }
     MParContainer(const MParContainer &named);
     MParContainer& operator=(const MParContainer& rhs);
@@ -69,6 +69,6 @@
     virtual void     Reset() {};
 
-    virtual Bool_t HasChanged() { return fHasChanged; }
-    virtual void   SetHasChanged(Bool_t flag=kTRUE) { fHasChanged=flag; }
+    virtual Bool_t IsReadyToSave() { return fReadyToSave; }
+    virtual void   SetReadyToSave(Bool_t flag=kTRUE) { fReadyToSave=flag; }
 
     virtual void AsciiRead(ifstream &fin);
Index: trunk/MagicSoft/Mars/mbase/MParList.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MParList.cc	(revision 852)
+++ trunk/MagicSoft/Mars/mbase/MParList.cc	(revision 855)
@@ -265,5 +265,5 @@
 //   itself) to unchanged
 //
-void MParList::SetHasChanged(Bool_t flag)
+void MParList::SetReadyToSave(Bool_t flag)
 {
     TIter Next(&fContainer);
@@ -275,7 +275,7 @@
     //
     while ( (cont=(MParContainer*)Next()) )
-        cont->SetHasChanged(flag);
-
-    MParContainer::SetHasChanged(flag);
+        cont->SetReadyToSave(flag);
+
+    MParContainer::SetReadyToSave(flag);
 }
 
Index: trunk/MagicSoft/Mars/mbase/MParList.h
===================================================================
--- trunk/MagicSoft/Mars/mbase/MParList.h	(revision 852)
+++ trunk/MagicSoft/Mars/mbase/MParList.h	(revision 855)
@@ -45,5 +45,5 @@
 
     void Reset();
-    void SetHasChanged(Bool_t flag=kTRUE);
+    void SetReadyToSave(Bool_t flag=kTRUE);
 
     void Print(Option_t *t = NULL);
Index: trunk/MagicSoft/Mars/mbase/MReadTree.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MReadTree.cc	(revision 852)
+++ trunk/MagicSoft/Mars/mbase/MReadTree.cc	(revision 855)
@@ -35,4 +35,7 @@
 // outside. It makes also possible to go back by decreasing the number.    //
 //                                                                         //
+// If you don't want to start reading the first event you have to call     //
+// MReadTree::SetEventNum after instantiating your MReadTree-object.       //
+//                                                                         //
 /////////////////////////////////////////////////////////////////////////////
 
@@ -178,4 +181,5 @@
         // the actual branch should be stored - enable branch.
         //
+        // FIXME: is it correct, that the pointer is deleted immediatly afterwards?
         branch->SetAddress(&pcont);
     }
@@ -190,4 +194,5 @@
 //  (Remark: The position can also be set by some member functions
 //  If the end of the file is reached the Eventloop is stopped.
+//
 Bool_t MReadTree::Process()
 {
@@ -267,6 +272,6 @@
 // this function makes Process() read event number nr next
 //
-// Remark: You can use this function to set the event number from which
-//         you want to start reading.
+// Remark: You can use this function after instatiating you MReadTree-object
+//         to set the event number from which you want to start reading.
 //
 Bool_t MReadTree::SetEventNum(UInt_t nr)
Index: trunk/MagicSoft/Mars/mbase/MTaskList.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MTaskList.cc	(revision 852)
+++ trunk/MagicSoft/Mars/mbase/MTaskList.cc	(revision 855)
@@ -59,13 +59,17 @@
 MTaskList::MTaskList(MTaskList &ts)
 {
-  fTasks.AddAll(&ts.fTasks);
-}
-
-// --------------------------------------------------------------------------
-//
-//  create the Iterator over the tasklist
+    fTasks.AddAll(&ts.fTasks);
+}
+
+// --------------------------------------------------------------------------
+//
+//  Set the logging stream for the all tasks in the list and the tasklist
+//  itself.
 //
 void MTaskList::SetLogStream(MLog *log)
 {
+    //
+    // create the Iterator over the tasklist
+    //
     TIter Next(&fTasks);
 
@@ -167,8 +171,11 @@
 {
     //
-    // Reset the HasChanged flag.
+    // Reset the ReadyToSave flag.
     // Reset all containers.
     //
-    fParList->SetHasChanged(kFALSE);
+    // FIXME: To run a tasklist as a single task in another tasklist we
+    //        have to make sure, that the Parameter list isn't reset.
+    //
+    fParList->SetReadyToSave(kFALSE);
     fParList->Reset();
 
@@ -231,8 +238,11 @@
 
     //
-    // Reset the HasChanged flag.
+    // Reset the ReadyToSave flag.
     // Reset all containers.
     //
-    fParList->SetHasChanged(kFALSE);
+    // FIXME: To run a tasklist as a single task in another tasklist we
+    //        have to make sure, that the Parameter list isn't reset.
+    //
+    fParList->SetReadyToSave(kFALSE);
     fParList->Reset();
 
Index: trunk/MagicSoft/Mars/mbase/MWriteRootFile.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MWriteRootFile.cc	(revision 852)
+++ trunk/MagicSoft/Mars/mbase/MWriteRootFile.cc	(revision 855)
@@ -322,5 +322,5 @@
         // Check for the Write flag
         //
-        if (!entry->GetContainer()->HasChanged())
+        if (!entry->GetContainer()->IsReadyToSave())
             continue;
 

Index: trunk/MagicSoft/Mars/mbase/MWriteAsciiFile.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MWriteAsciiFile.cc	(revision 852)
+++ trunk/MagicSoft/Mars/mbase/MWriteAsciiFile.cc	(revision 855)
@@ -32,5 +32,5 @@
 // This can be the name of the class or a given name, which identifies     //
 // the container in a parameter container list (MParList).                 //
 // The container is writte to the ascii file if its HasChanged flag is     //
 // set (MParContainer)                                                     //
 //                                                                         //
@@ -102,5 +102,5 @@
 void MWriteAsciiFile::CheckAndWrite() const
 {
-    if (fContainer->HasChanged())
+    if (fContainer->IsReadyToSave())
         fContainer->AsciiWrite(*fOut);
 }
@@ -32,5 +32,5 @@
 // This can be the name of the class or a given name, which identifies     //
 // the container in a parameter container list (MParList).                 //
-// The container is writte to the ascii file if its HasChanged flag is     //
+// The container is writte to the ascii file if its ReadyToSave flag is     //
 // set (MParContainer)                                                     //
 //                                                                         //